@@ -1,6 +1,7 @@
 (function() {
     'use strict';
     /** @typedef {import('../../simple_report/types').GeneratedSources.ChartFilter} ChartFilter */
+    /** @typedef {import('../../simple_report/types').GeneratedSources.FilterFacet} FilterFacet */
     /** @typedef {import('../../simple_report/types').GeneratedSources.DashboardPage} DashboardPage */
 
     const app = angular.module('dataiku.dashboards');
@@ -9,18 +10,26 @@
      * Everything to store and manipulate dashboard filters.
      * Was previously located here: src/main/platypus/static/dataiku/js/dashboards/core.js
      */
-    app.factory('DashboardFilters', function(CHART_FILTERS, FILTERABLE_INSIGHT_TYPES, DashboardFiltersUrlParams, ChartFilterUtils, FiltersPanelPosition, ActivityIndicator, ChartTypeChangeHandler, ChartFilters, FilterFacetsService, Logger, DataikuAPI, ChartUsableColumns, FilterPanelContext, $stateParams, CachedAPICalls, DashboardPageUtils, TileUtils) {
-        const FILTERS_ON_MSG = 'Data is filtered';
+    app.factory('DashboardFilters', function($rootScope, CHART_FILTERS, FILTERABLE_INSIGHT_TYPES, DashboardFiltersUrlParams, ChartFilterUtils, FiltersPanelPosition, ActivityIndicator, ChartTypeChangeHandler, ChartFilters, FilterFacetsService, Logger, DataikuAPI, ChartUsableColumns, MonoFuture, FilterPanelContext, $stateParams, CachedAPICalls, DashboardPageUtils, TileUtils, translate, DashboardFilterSynchronizationService) {
+        const FILTERS_ON_MSG = translate('DASHBOARD.FILTERS.STATUS.DATA_FILTERED', 'Data is filtered');
         const SAMPLING_PROPS = ['refreshableSelection', 'engineType'];
         const MAX_DATA_BYTES = -1; // default to no memory limit (for sampling)
         const filtersSourceTypes = Object.freeze({ DATASET: 'dataset', TILE: 'tile' });
 
         /** @type {Map<string, ChartFilter[]>} */
-        const globalFiltersByPageId = new Map();
+        const globalFiltersByPageClientId = new Map();
+        /** @type {Map<string, FilterFacet[]>} */
+        const dashboardFiltersFacetsByPageClientId = new Map();
+        /** @type {Map<string, ChartFilter[]>} */
+        const insightsFiltersFacetsByInsightId = new Map();
+        /** @type {Map<string, boolean>} */
+        const insightAllFiltersFacetsByInsightId = new Map();
+        /** @type {Map<string, boolean>} */
+        const insightAllFiltersByInsightId = new Map();
         /** @type {Map<string, boolean>} */
         const enableCrossFiltersByPageId = new Map();
         /** @type {Map<string, boolean>} */
-        const isFilterPanelDeactivatedByPageId = new Map();
+        const isFilterPanelDeactivatedByPageClientId = new Map();
         let insightsMap; // get all insights on dashboard mapped by id
 
         const lowerCaseStatusByDatasetKey = new Map(); // store the lower case status of each dataset
@@ -56,30 +65,83 @@
         }
 
         function resetAllDashboardPagesFilterPanelStates() {
-            globalFiltersByPageId.clear();
-            isFilterPanelDeactivatedByPageId.clear();
+            globalFiltersByPageClientId.clear();
+            insightsFiltersFacetsByInsightId.clear();
+            isFilterPanelDeactivatedByPageClientId.clear();
             enableCrossFiltersByPageId.clear();
         }
 
-        function resetGlobalFilters(pageId) {
-            globalFiltersByPageId.delete(pageId);
+        function resetGlobalFilters(pageClientId) {
+            globalFiltersByPageClientId.delete(pageClientId);
         }
 
-        function setGlobalFilters(filters, pageId) {
-            if (filters !== globalFiltersByPageId.get(pageId) && pageId) {
-                globalFiltersByPageId.set(pageId, filters);
+        function setGlobalFilters(filters, pageClientId) {
+            if (filters !== globalFiltersByPageClientId.get(pageClientId) && pageClientId) {
+                globalFiltersByPageClientId.set(pageClientId, filters);
             }
         }
 
-        function getGlobalFilters(pageId) {
-            return globalFiltersByPageId.get(pageId);
+        function getGlobalFilters(pageClientId) {
+            return globalFiltersByPageClientId.get(pageClientId);
         }
 
-        function getActiveGlobalFilters(pageId) {
-            if (getIsFilterPanelDeactivated(pageId)) {
+        function setDashboardFiltersFacets(filters, pageClientId) {
+            if (filters !== dashboardFiltersFacetsByPageClientId.get(pageClientId) && pageClientId) {
+                dashboardFiltersFacetsByPageClientId.set(pageClientId, filters);
+                DashboardFilterSynchronizationService.sendDashboardFilterFacetsUpdatedEvent();
+            }
+        }
+
+        function getDashboardFiltersFacets(pageClientId) {
+            return dashboardFiltersFacetsByPageClientId.get(pageClientId);
+        }
+
+        function getActiveGlobalFilters(pageClientId) {
+            if (getIsFilterPanelDeactivated(pageClientId)) {
                 return [];
             }
-            return globalFiltersByPageId.get(pageId);
+            return globalFiltersByPageClientId.get(pageClientId);
+        }
+
+        function setAllInsightFiltersFacets(filters, insightId) {
+            if (filters !== insightAllFiltersFacetsByInsightId.get(insightId) && insightId) {
+                insightAllFiltersFacetsByInsightId.set(insightId, filters);
+            }
+        }
+
+        // Return both insight + dashboard facets for this insight
+        function getAllInsightFiltersFacets(insightId) {
+            if(insightAllFiltersFacetsByInsightId.get(insightId)) {
+                return insightAllFiltersFacetsByInsightId.get(insightId);
+            }
+            return [];
+        }
+
+        function setAllInsightFilters(filters, insightId) {
+            if (filters !== insightAllFiltersByInsightId.get(insightId) && insightId) {
+                insightAllFiltersByInsightId.set(insightId, filters);
+            }
+        }
+
+        // Return both insight + dashboard filters for this insight
+        function getAllInsightFilters(insightId) {
+            if(insightAllFiltersByInsightId.get(insightId)) {
+                return insightAllFiltersByInsightId.get(insightId);
+            }
+            return [];
+        }
+
+        function setInsightsFiltersFacets(filters, insightId) {
+            if (filters !== insightsFiltersFacetsByInsightId.get(insightId) && insightId) {
+                insightsFiltersFacetsByInsightId.set(insightId, filters);
+            }
+        }
+
+        function getInsightsFiltersFacets(insightId) {
+            if(insightsFiltersFacetsByInsightId.get(insightId)) {
+                return insightsFiltersFacetsByInsightId.get(insightId);
+            }
+            return [];
         }
 
         function setInsightsMap(newInsightsMap) {
@@ -94,7 +156,7 @@
             const filterableTiles = [];
             const dashboardPageIdx = findDashboardPageIdx(dashboardPageId, dashboardPages);
             if (dashboardPageIdx > -1 && insightsMap) {
-                dashboardPages[dashboardPageIdx].grid.tiles.forEach((tile) => {
+                TileUtils.getFlattenedTileList(dashboardPages[dashboardPageIdx].grid.tiles).forEach(tile => {
                     if (FILTERABLE_INSIGHT_TYPES.includes(tile.insightType)) {
                         const mappedInsight = insightsMap[tile.insightId];
                         if (!mappedInsight) {
@@ -208,11 +270,11 @@
                 return '';
             }
             if (tileData.sourceDataset !== filtersParams.datasetSmartName) {
-                return 'datasets are different';
+                return translate('DASHBOARD.FILTERS.STATUS.UNUSABLE_DIFFERENT_DATASETS', 'datasets are different');
             }
             // no sense on checking for samples if datasets are different
             if (!isSameSampling(tileData.sampleSettings.selection, filtersParams.refreshableSelection.selection)) {
-                return 'samples are different';
+                return translate('DASHBOARD.FILTERS.STATUS.UNUSABLE_DIFFERENT_SAMPLES', 'samples are different');
             }
             return '';
         }
@@ -228,27 +290,26 @@
             const isPluralColumns = unusableFilters.length > 1 ? 's' : '';
             const isPluralOthers = otherColumnsLength > 1 ? 's' : '';
             const hasDifferentReasons = unusableFilters.slice(1).some(uf => uf.reason !== unusableFilters[0].reason);
-            return `${FILTERS_ON_MSG} - except for column${isPluralColumns} ${columnsNames}\
-                    ${otherColumnsLength > 0 ? ` + ${otherColumnsLength} other${isPluralOthers}` : ''} (\
-                        ${hasDifferentReasons ? 'various reasons' : unusableFilters[0].reason}\
-                        ${hasWarningRootCause ? `as ${warningRootCause}` : ''}\
+            return `${FILTERS_ON_MSG} - ${translate('DASHBOARD.FILTERS.STATUS.EXCEPT_COLUMN', `except for column${isPluralColumns}`, { columnCount: unusableFilters.length })} ${columnsNames}\
+                    ${otherColumnsLength > 0 ? ` + ${translate('DASHBOARD.FILTERS.STATUS.OTHER_COLUMNS', `${otherColumnsLength} other${isPluralOthers}`, { otherColumnCount: otherColumnsLength })}` : ''} (\
+                        ${hasDifferentReasons ? translate('DASHBOARD.FILTERS.STATUS.UNUSABLE_VARIOUS_REASONS', 'various reasons') : unusableFilters[0].reason}\
+                        ${hasWarningRootCause ? `${translate('DASHBOARD.FILTERS.STATUS.AS', 'as')} ${warningRootCause}` : ''}\
                     )`;
         }
 
         function setFilteringMessages(tileData, filtersParams) {
-            if (!tileData.filteringStatus.isInsightFiltered) {
-                tileData.filteringStatus.warningMessage = '';
-                tileData.filteringStatus.infoMessage = '';
+            if (!tileData.tileFilteringInformation.isInsightFiltered) {
+                tileData.tileFilteringInformation.warningMessage = '';
+                tileData.tileFilteringInformation.infoMessage = '';
                 return;
             }
             const inconsistentFilteringCause = getInconsistentFilteringCause(tileData, filtersParams);
             if (!inconsistentFilteringCause.length && !tileData.unusableColumnsFilters.length) {
-                tileData.filteringStatus.warningMessage = ''; // no warning message if no inconsistent filtering detected cause detected
-                tileData.filteringStatus.infoMessage = FILTERS_ON_MSG;
+                tileData.tileFilteringInformation.warningMessage = ''; // no warning message if no inconsistent filtering detected cause detected
             } else {
-                tileData.filteringStatus.warningMessage = getUnusableFiltersMessage(tileData.unusableColumnsFilters, inconsistentFilteringCause);
-                tileData.filteringStatus.infoMessage = tileData.filteringStatus.warningMessage.length > 0 ? ''
-                    : `${FILTERS_ON_MSG} - risk of inconsistency (${inconsistentFilteringCause})`;
+                tileData.tileFilteringInformation.warningMessage = getUnusableFiltersMessage(tileData.unusableColumnsFilters, inconsistentFilteringCause);
+                tileData.tileFilteringInformation.infoMessage = tileData.tileFilteringInformation.warningMessage.length > 0 ? ''
+                    : `${FILTERS_ON_MSG} - ${translate('DASHBOARD.FILTERS.STATUS.RISK_INCONSISTENCY', `risk of inconsistency (${inconsistentFilteringCause})`, { reason: inconsistentFilteringCause })}`;
             }
         }
 
@@ -293,17 +354,17 @@
             if (filter && usableColumns && usableColumns.length) {
                 const columnFound = usableColumns.find(e => e.column === filter.column);
                 if (columnFound && columnFound.type !== filter.type) {
-                    return 'type mismatch';
+                    return translate('DASHBOARD.FILTERS.STATUS.UNUSABLE_TYPE_MISMATCH', 'type mismatch');
                 }
             }
-            return 'not found';
+            return translate('DASHBOARD.FILTERS.STATUS.UNUSABLE_NOT_FOUND', 'not found');
         }
 
         function getUnusableColumnFilters(filters, usableColumns) {
             if (usableColumns && usableColumns.length && filters && filters.length) {
                 return filters
                     .filter(filter => !hasUsableColumn(usableColumns, filter))
-                    .map(filter => ({ columnName: filter.column, reason: getReason(filter, usableColumns) }));
+                    .map(filter => ({ columnName: ChartFilterUtils.isExplicitFilter(filter) ? filter.explicitConditions.flatMap(it => it.column) : filter.column, reason: getReason(filter, usableColumns) }));
             }
             return [];
         }
@@ -327,47 +388,55 @@
         }
 
         function onApplyFiltersSuccess(tileData, filtersParams, response) {
-            tileData.filteringStatus.isApplyingFilters = false;
-            tileData.filteringStatus.isInsightFiltered = hasGlobalFiltersApplied(response, tileData.appliedFilters);
+            tileData.tileFilteringInformation.isApplyingFilters = false;
+            tileData.tileFilteringInformation.isInsightFiltered = hasGlobalFiltersApplied(response, tileData.appliedFilters);
+            updateFiltersDetails(tileData.tileFilteringInformation.filtersDetails, response);
             setFilteringMessages(tileData, filtersParams);
         }
 
-        function onApplyFiltersError(error, filteringStatus, loadingData) {
-            filteringStatus.isApplyingFilters = false;
+        function onApplyFiltersError(error, tileFilteringInformation, loadingData) {
+            tileFilteringInformation.isApplyingFilters = false;
 
             if (!error || !error.data) {
                 return;
             }
-
             // If the error contains a filtered out message, the insight is considered as filtered (empty state)
-            filteringStatus.isInsightFiltered = error.data.message.includes('filtered out');
+            tileFilteringInformation.isInsightFiltered = error.data.message.includes('filtered out');
 
 
-            if (!filteringStatus.isInsightFiltered && error.data.message.includes('To finish your chart')) {
+            if (!tileFilteringInformation.isInsightFiltered && error.data.message.includes('To finish your chart')) {
                 loadingData.unconfiguredRoutine();
             }
         }
 
         function applyFilters(filters, filtersParams, tileData, loadingData, hasCaseInsensitiveColumnNames) {
-            if (!tileData.usableColumns) {
-                return;
+            try {
+                if (!tileData.usableColumns) {
+                    return;
+                }
+
+                // Remove non usable columns
+                let matchingFilters = getUsableFilters(filters, tileData.usableColumns, hasCaseInsensitiveColumnNames, filtersParams);
+                if (hasCaseInsensitiveColumnNames && matchingFilters.length > 0) {
+                    matchingFilters = getFiltersWithCorrectCaseColumnNames(matchingFilters, tileData.usableColumns);
+                }
+
+                tileData.appliedFilters = angular.copy(matchingFilters);
+                tileData.unusableColumnsFilters = getUnusableColumnFilters(filters, tileData.usableColumns);
+                tileData.tileFilteringInformation.isApplyingFilters = !!matchingFilters && !!matchingFilters.length;
+                // we cannot use matching filters as their min/max values may have changed and compromised the tooltip
+                tileData.tileFilteringInformation.filtersDetails = createFiltersDetails(filters.filter(filter => isFilterEffective(filter, filtersParams)));
+
+                return tileData.applyFilters(matchingFilters, loadingData)
+                    .then(data => tileData.parseResponse ? onApplyFiltersSuccess(tileData, filtersParams, tileData.parseResponse(data)) : data)
+                    .catch((error) => {
+                        onApplyFiltersError(error, tileData.tileFilteringInformation, loadingData);
+                        // Let the insight handle the error
+                        throw error;
+                    });
+            } catch (error) {
+                return Promise.reject(error);
             }
-
-            // Remove non usable columns
-            let matchingFilters = getUsableFilters(filters, tileData.usableColumns, hasCaseInsensitiveColumnNames, filtersParams);
-            if (hasCaseInsensitiveColumnNames && matchingFilters.length > 0) {
-                matchingFilters = getFiltersWithCorrectCaseColumnNames(matchingFilters, tileData.usableColumns);
-            }
-
-            tileData.appliedFilters = angular.copy(matchingFilters);
-            tileData.unusableColumnsFilters = getUnusableColumnFilters(filters, tileData.usableColumns);
-            tileData.filteringStatus.isApplyingFilters = !!matchingFilters && !!matchingFilters.length;
-
-            return tileData.applyFilters(matchingFilters, loadingData)
-                .then(data => tileData.parseResponse ? onApplyFiltersSuccess(tileData, filtersParams, tileData.parseResponse(data)) : data)
-                .catch((error) => {
-                    onApplyFiltersError(error, tileData.filteringStatus, loadingData);
-                });
         }
 
         function getFiltersWithCorrectCaseColumnNames(matchingFilters, usableColumns) {
@@ -438,6 +507,9 @@
                     facet.dateFilterType = filter.dateFilterType;
                     facet.dateFilterPart = filter.dateFilterPart;
                 }
+                if (filter.useMinimalUi) {
+                    facet.useMinimalUi = filter.useMinimalUi;
+                }
                 const alphanumFilter = {
                     isAGlobalFilter: filter.isAGlobalFilter,
                     type: 'alphanum',
@@ -463,6 +535,7 @@
                 explorationFilters.push({
                     column: filter.column,
                     type: 'columnFilter',
+                    label: filter.label ?? filter.column,
                     currentMode: filter.filterSelectionType === 'CUSTOM' ? 'SIMPLE_ALPHANUM' : 'FACET',
                     active: filter.active,
                     facet,
@@ -472,6 +545,82 @@
             return explorationFilters;
         }
 
+        /**
+         * Get charts filters from explorations filters
+         * @param  {List<FilterElement.java>} filtersElements - Filters to convert from
+         * @return {List<ChartFilter.java>}
+         */
+        function getChartsFiltersFromFiltersElements(filtersElements) {
+            if (!filtersElements || !filtersElements.length) {
+                return [];
+            }
+            const chartsFilters = [];
+            filtersElements.forEach(filter => {
+                const chartFilter = {
+                    active: filter.active,
+                    column: filter.column,
+                    columnType: filter.facet.columnType,
+                    filterType: filter.facet.currentMode === 'EXPLICIT' ? 'EXPLICIT' : filter.facet.currentMode + '_FACET',
+                    minValue: filter.facet.minValue,
+                    maxValue: filter.facet.maxValue,
+                    isAGlobalFilter: filter.facet.isAGlobalFilter ?? false,
+                    isA: 'filter',
+                    includeEmptyValues: filter.includeEmptyValues || filter.facet.includeEmptyValues,
+                    label: filter.label,
+                    $isFromExploration: true
+                };
+
+                if (filter.facet.currentMode === 'EXPLICIT' || filter.facet.useMinimalUi) {
+                    chartFilter.useMinimalUi = true;
+                }
+
+                if (filter.facet.explicitConditions) {
+                    chartFilter.explicitConditions = filter.facet.explicitConditions;
+                }
+                if (filter.facet.explicitExclude) {
+                    chartFilter.explicitExclude = filter.facet.explicitExclude;
+                }
+
+                if (filter.facet.selectedValues) {
+                    chartFilter.excludeOtherValues = true;
+                    chartFilter.selectedValues = filter.facet.selectedValues;
+                } else {
+                    chartFilter.excludedValues = filter.facet.excludedValues;
+                }
+
+                if (filter.alphanumFilter.selectedValues && filter.alphanumFilter.selectedValues.length > 0) {
+                    const isCustomFilter = filter.currentMode === 'SIMPLE_ALPHANUM';
+                    chartFilter.customOptions = isCustomFilter ? {
+                        matchingMode: filter.alphanumFilter.params.mode.toUpperCase(),
+                        normalizationMode: filter.alphanumFilter.params.normalization.toUpperCase()
+                    } : {};
+                    // overrides values of the facet
+                    const newValues = filter.alphanumFilter.selectedValues.reduce((acc, val) => {
+                        acc[val] = true;
+                        return acc;
+                    }, {});
+                    chartFilter.selectedValues = newValues;
+                    chartFilter.filterSelectionType = isCustomFilter ? 'CUSTOM' : 'MULTI_SELECT';
+                    chartFilter.filterType = isCustomFilter ? 'ALPHANUM' : 'ALPHANUM_FACET';
+                }
+
+                if (filter.facet.dateFilterType === CHART_FILTERS.DATE_TYPES.RANGE) {
+                    chartFilter.dateFilterType = filter.facet.dateFilterType;
+                } else if (filter.facet.dateFilterType === CHART_FILTERS.DATE_TYPES.RELATIVE) {
+                    chartFilter.dateFilterType = filter.facet.dateFilterType;
+                    chartFilter.dateFilterPart = filter.facet.dateFilterPart;
+                    chartFilter.dateFilterOption = filter.facet.dateFilterRelativeOption;
+                    chartFilter.dateFilterRelativePreset = filter.facet.dateFilterRelativePreset;
+                } else if (filter.facet.dateFilterType === CHART_FILTERS.DATE_TYPES.PART) {
+                    chartFilter.dateFilterType = filter.facet.dateFilterType;
+                    chartFilter.dateFilterPart = filter.facet.dateFilterPart;
+                }
+
+                chartsFilters.push(chartFilter);
+            });
+            return chartsFilters;
+        }
+
         /**
          * Computes the initial state of a dashboard slide filters, store them in the service and returns them.
          * @param {DashboardPage} page
@@ -481,22 +630,22 @@
          */
         function initPageFilters(page, urlQueryParams, insights) {
             const filtersAreInSearchParams = DashboardFiltersUrlParams.areFiltersInSearchParams(urlQueryParams);
-            const previousFilters = getGlobalFilters(page.id) || getPageFilters(page);
+            const previousFilters = getGlobalFilters(page.cid) || getPageFilters(page);
 
             if (filtersAreInSearchParams) {
                 return getFilterPanelUsableColumns(page.filtersParams, urlQueryParams, insights)
                     .then(usableColumns => applyUrlFiltersOnPageFilters(urlQueryParams, previousFilters, usableColumns))
                     .then((filters) => {
                         if (filters) {
-                            setGlobalFilters(filters, page.id);
+                            setGlobalFilters(filters, page.cid);
                             return { activeFilters: filters, filters };
                         }
                         return [];
                     });
             }
-            setGlobalFilters(previousFilters, page.id);
+            setGlobalFilters(previousFilters, page.cid);
             return Promise.resolve({
-                activeFilters: getActiveGlobalFilters(page.id) || previousFilters,
+                activeFilters: getActiveGlobalFilters(page.cid) || previousFilters,
                 filters: previousFilters
             });
         }
@@ -585,16 +734,16 @@
             return newFilters;
         }
 
-        function setIsFilterPanelDeactivated(pageId, isDeactivated) {
-            isFilterPanelDeactivatedByPageId.set(pageId, isDeactivated);
+        function setIsFilterPanelDeactivated(pageClientId, isDeactivated) {
+            isFilterPanelDeactivatedByPageClientId.set(pageClientId, isDeactivated);
         }
 
-        function getIsFilterPanelDeactivated(pageId) {
-            return !!isFilterPanelDeactivatedByPageId.get(pageId);
+        function getIsFilterPanelDeactivated(pageClientId) {
+            return !!isFilterPanelDeactivatedByPageClientId.get(pageClientId);
         }
 
         function acceptColumnAsFilter(data) {
-            const ret = ChartTypeChangeHandler.stdAggregatedAcceptDimension(data);
+            const ret = ChartTypeChangeHandler.stdAggregatedAcceptDimensionOrHierarchy(data);
             return ret.accept && data.type !== 'GEOMETRY' && data.type !== 'GEOPOINT';
         }
 
@@ -740,6 +889,21 @@
             lowerCaseStatusByDatasetKey.clear();
         }
 
+        function updateFiltersDetails(filtersDetails, pivotResponse) {
+            // this is mainly for datasets filters facets
+            filtersDetails.insightsFiltersFacets = pivotResponse.filterFacets.filter(f => !f.isAGlobalFilter);
+            filtersDetails.allFiltersFacets = pivotResponse.filterFacets;
+        }
+
+        function createFiltersDetails(filters) {
+            return {
+                insightsFiltersFacets: [],
+                insightFilters: [],
+                allFilters: [...filters] ,
+                allFiltersFacets: []
+            };
+        }
+
         return {
             SAMPLING_PROPS,
             MAX_DATA_BYTES,
@@ -777,7 +941,16 @@
             isFiltersPanelDocked,
             hasCaseInsensitiveColumnNames,
             flushDatasetLowerCaseStatus,
-            resetAllDashboardPagesFilterPanelStates
+            resetAllDashboardPagesFilterPanelStates,
+            setInsightsFiltersFacets,
+            getInsightsFiltersFacets,
+            getChartsFiltersFromFiltersElements,
+            getAllInsightFiltersFacets,
+            getAllInsightFilters,
+            setAllInsightFilters,
+            setAllInsightFiltersFacets,
+            setDashboardFiltersFacets,
+            getDashboardFiltersFacets
         };
     });
 })();
