@@ -82,7 +82,7 @@
 
     app.controller('_DeployerBaseController', function($rootScope, $scope, TaggingService, DataikuCloudService) {
         /**
-         * Get the link to the extensions 
+         * Get the link to the extensions
          */
         const getLaunchpadExtensionsLink = function() {
             DataikuCloudService.getCloudInfo().then(cloudInfo => {
@@ -94,7 +94,11 @@
 
         TaggingService.fetchGlobalTags();
         $scope.isCloud = DataikuCloudService.isDataikuCloud();
-        $scope.onlyForDataikerAdminWhenInCloud = $scope.isCloud ? $rootScope.appConfig.canAccessCloudDataikerAdminCapabilities : true;
+
+        const appConfig = $rootScope.appConfig;
+
+        $scope.onlyForDataikerAdminWhenInCloud = !$scope.isCloud || appConfig.canAccessCloudDataikerAdminCapabilities;
+        $scope.isK8sInfraCreationDisabled = $scope.isCloud && !appConfig.isCloudK8sInfraCreationEnabled;
 
         if($scope.isCloud) {
             getLaunchpadExtensionsLink();
