@@ -26,6 +26,13 @@ var app = angular.module('dataiku.controllers');
        $scope.acceptDeferred = null;
        $scope.dismiss();
    };
+   $scope.confirmAndFixAllAvailablePartitioning = function() {
+       if($scope.acceptDeferred) {
+           $scope.acceptDeferred.resolve("shouldFixAllAvailablePartitioning");
+       }
+       $scope.acceptDeferred = null;
+       $scope.dismiss();
+   };
 });
 
 
@@ -145,7 +152,7 @@ app.controller('PasteModalController', function($scope, DetectUtils, WT1) {
     };
 });
 
-app.controller('ShareInWorkspaceDialogController', function($scope, DataikuAPI, $state, WorkspaceDisplayService, WT1) {
+app.controller('ShareInWorkspaceDialogController', function($scope, DataikuAPI, $state, WorkspaceDisplayService, WT1, ActivityIndicator, StateUtils) {
     const shareInWorkspaceDialogCtrl = this;
 
     // Exposed objects
@@ -194,23 +201,24 @@ app.controller('ShareInWorkspaceDialogController', function($scope, DataikuAPI,
     });
 
     function getModalTitle(selectedObjects) {
-        let modalTitle;
-
-        switch (selectedObjects.length) {
-            case 1:
-                if (selectedObjects[0].reference) {
-                    modalTitle = `Publish ${selectedObjects[0].reference.type.toLowerCase()} in workspace`;
-                } else if (selectedObjects[0].appId) {
-                    modalTitle = "Publish application in workspace";
-                } else {
-                    modalTitle = "Publish object on a workspace";
-                }
-            break;
-            default:
-                modalTitle = `Share ${ selectedObjects.length } objects in workspace`;
-            break;
+        let objectsLabel = getObjectsAndQuantityLabel(selectedObjects).toLowerCase();
+        if(selectedObjects.length === 1) {
+            return `Publish ${objectsLabel} in workspace`;
         }
-        return modalTitle;
+        return `Share ${objectsLabel} in workspace`;
+    }
+
+    function getObjectsAndQuantityLabel(selectedObjects) {
+        if(selectedObjects.length === 1) {
+            if (selectedObjects[0].reference) {
+                return selectedObjects[0].reference.type.toLowerCase();
+            } else if (selectedObjects[0].appId) {
+                return 'Application';
+            } else {
+                return 'Object';
+            }
+        }
+        return `${selectedObjects.length} objects`;
     }
 
     DataikuAPI.workspaces.list("WRITE").success(workspacesList => {
@@ -232,14 +240,22 @@ app.controller('ShareInWorkspaceDialogController', function($scope, DataikuAPI,
             objectsToShare.forEach(object =>
                 WT1.event('workspaces-add-object-success', { from: 'share', objectType: WorkspaceDisplayService.getObjectType(object), multi })
             );
-            $state.transitionTo('workspaces.workspace', { workspaceKey: shareInWorkspaceDialogCtrl.workspaceKey });
+            ActivityIndicator.success(`${getObjectsAndQuantityLabel(objectsToShare)} added to workspace!${buildLinkToWorkspace()}`, 5000);
+            $scope.dismiss();
         }).error((data, status, headers, config, statusText) => {
             setErrorInScope.bind($scope.errorScope || $scope.$parent)(data, status, headers, config, statusText);
         });
     }
+
+    function buildLinkToWorkspace() {
+        const href = StateUtils.href.workspace(shareInWorkspaceDialogCtrl.workspaceKey);
+        const workspaceName = shareInWorkspaceDialogCtrl.workspacesList.filter(ws => ws.workspaceKey === shareInWorkspaceDialogCtrl.workspaceKey)[0].displayName;
+        const linkMessage = `View in ${sanitize(workspaceName)}`;
+        return `<div><a href='${href}'>${linkMessage}</a>.<div>`;
+    }
 });
 
-app.controller('AddToDataCollectionDialogController', function($scope, $rootScope, DataikuAPI, ActivityIndicator, StateUtils, WT1, $q, $state, CreateModalFromTemplate, ActiveProjectKey) {
+app.controller('AddToDataCollectionDialogController', function($scope, $rootScope, DataikuAPI, ActivityIndicator, StateUtils, WT1, $q, $state, CreateModalFromTemplate) {
     // This modal is used from many places (in the object's source project, in a project they are shared to, in the data catalog...). Be careful to not add code that relies on any assumption about which page is currently opened.
 
     const $ctrl = this;
@@ -333,6 +349,19 @@ app.controller('AddToDataCollectionDialogController', function($scope, $rootScop
     }
 
     $ctrl.generateDatasetDescription = function(obj) {
+        const icon = getDatasetCompletenessInfo(obj).icon;
+        const iconLevel = $ctrl.ICONS_METADATA.indexOf(icon);
+        const dataCollectionh = $ctrl.dataCollectionItem === undefined ? "undefined" : md5($ctrl.dataCollectionItem.id);
+        WT1.event('data-collection-add-description-click', {
+            from: 'publish',
+            columnsDescriptionCheck: $ctrl.dataCollectionItem?.metadataCompletenessChecks?.columnsDescriptionCheck,
+            longDescriptionCheck: $ctrl.dataCollectionItem?.metadataCompletenessChecks?.longDescriptionCheck,
+            hasLongDescription: obj.hasLongDescription,
+            allColumnsHaveDescription: obj.numberOfEmptyColumns === 0,
+            iconLevel: iconLevel,
+            dataseth: md5(obj.id),
+            dataCollectionh: dataCollectionh,
+        });
         if ($ctrl.canWriteProject === undefined) {
             //from the data catalog page, we have no project, so no $rootScope.topNav.isProjectAnalystRW;
             DataikuAPI.projects.getSummary(obj.projectKey).success(data => {
@@ -562,6 +591,19 @@ app.controller('AddToDataCollectionDialogController', function($scope, $rootScop
         DataikuAPI.dataCollections.addObjects($ctrl.dataCollectionItem.id, $ctrl.filteredSelectedObjects.map(addObjectFromSelectedObject)).success((response) => {
             const collectionName = $ctrl.dataCollectionsList.find(dataCollection => dataCollection.id === $ctrl.dataCollectionItem.id).metadata.displayName;
             succeeded = true;
+
+            const nbObjectsWithLongDesc = $ctrl.filteredSelectedObjects.filter(obj => obj.hasLongDescription).length;
+            const nbObjectsWithColumnsDesc = $ctrl.filteredSelectedObjects.filter(obj => obj.numberOfEmptyColumns === 0).length;
+            WT1.event('data-collection-objects-added', {
+                from: 'publish',
+                dataCollectionh: md5($ctrl.dataCollectionItem.id),
+                objectsCount: $ctrl.filteredSelectedObjects.length,
+                objectsWithLongDesc: nbObjectsWithLongDesc,
+                objectsWithColumnDesc: nbObjectsWithColumnsDesc,
+                columnsDescriptionCheck: $ctrl.dataCollectionItem?.metadataCompletenessChecks?.columnsDescriptionCheck,
+                longDescriptionCheck: $ctrl.dataCollectionItem?.metadataCompletenessChecks?.longDescriptionCheck,
+            });
+
             const multi = $ctrl.filteredSelectedObjects?.length > 0;
             $ctrl.filteredSelectedObjects.forEach(object =>
                 WT1.tryEvent('data-collection-object-added', () => ({
@@ -845,6 +887,9 @@ app.factory("Dialogs", ["CreateModalFromTemplate", "$q", "$state", "$timeout","D
                 newScope.positive = false;
                 newScope.title = title;
                 newScope.text = text;
+                newScope.showFixPartitioningButton = (data?.messages || []).some(function(m) {
+                    return m.severity === 'WARNING' && m.code === 'ERR_DATASET_DANGEROUS_PARTITIONING_ACTIONABLE';
+                });
                 newScope.$on("$destroy",function() {
                     if(newScope.acceptDeferred) {
                         newScope.acceptDeferred.reject();
