@@ -3,7 +3,12 @@
 
     var app = angular.module('dataiku.directives.snippetEditor', ['dataiku.filters', 'dataiku.services', 'ui.keypress', 'dataiku.common.lists']);
 
-	app.directive('libDocumentationSwitch', function() {
+	app.constant("VIRTUAL_GROUPS", {
+		ALL_USERS_GROUP_DISPLAY: 'All Users',
+		ALL_USERS_GROUP_INTERNAL: '$$ALL_USERS$$'
+	});
+
+	app.directive('libDocumentationSwitch', function(WT1) {
 		return {
 			scope: {
 				editorParams: '='
@@ -12,6 +17,11 @@
 				//showing and hiding the codeSnippetEditorSampleSelector
 				$scope.switchLibsDocumentationVisibility = function() {
 					$scope.editorParams.libsDocumentationVisible = !$scope.editorParams.libsDocumentationVisible;
+                    if ($scope.editorParams.libsDocumentationVisible) {
+                        WT1.event('docportal-open', {
+                            embedded: true
+                        });
+                    }
 				}
 			},
 			templateUrl : '/templates/widgets/lib-documentation-switch.html'
@@ -21,7 +31,8 @@
 	app.directive('codeSnippetEditorSwitch', function() {
 		return {
 			scope: {
-				codeSamplesSelectorVisible: '='
+				codeSamplesSelectorVisible: '=',
+                iconOnly: '<'
 			},
 			controller : function($scope, $timeout) {
 				//showing and hiding the codeSnippetEditorSampleSelector
@@ -38,7 +49,7 @@
 	});
 
 
-	app.directive('codeSnippetSampleSelector', function() {
+	app.directive('codeSnippetSampleSelector', function(VIRTUAL_GROUPS) {
 		return {
 			restrict: 'E',
 			replace: true,
@@ -62,6 +73,18 @@
 	        	//-- reloadSampleListFunc: method used to reload the code sample list
 	        	$scope.reloadSampleListFunc = function() {
 	            	DataikuAPI.flow.snippets.getSnippets($scope.sampleType, $scope.categories).success(function(data) {
+						if (data) {
+							data.forEach(snippet => {
+								snippet?.permissions?.forEach(permission => {
+									if (permission.group === VIRTUAL_GROUPS.ALL_USERS_GROUP_INTERNAL) {
+										permission.displayGroup = VIRTUAL_GROUPS.ALL_USERS_GROUP_DISPLAY;
+									} else {
+										permission.displayGroup = permission.group;
+									}
+								});
+							});
+						}
+
 	            		$scope.recipeSamples = data;
 	                }).error(setErrorInScope.bind($scope));
 	        	}
@@ -115,7 +138,7 @@
 	            resolveCodeForInsertionFunc : '=?',
 	            displayed : '='
 	        },
-	        controller : function($scope, $element, $timeout, $stateParams, DataikuAPI, ListFilter, WT1, CodeMirrorSettingService) {
+	        controller : function($scope, $element, $timeout, $stateParams, DataikuAPI, ListFilter, WT1, CodeMirrorSettingService, VIRTUAL_GROUPS) {
 	        	//Checking editorOptions parameters
 	        	if (typeof($scope.editorOptions)==='undefined') {
                     $scope.editorOptions = CodeMirrorSettingService.get('text/x-python', {onLoad: function(cm) {$scope.codeMirror = cm;}});
@@ -174,6 +197,18 @@
 	        	$scope.reloadSampleListFunc = function() {
 	        		$scope.recipeSamples = [];
 	        		DataikuAPI.flow.snippets.getSnippets($scope.sampleType, $scope.categories).success(function(data) {
+						if (data) {
+							data.forEach(snippet => {
+								snippet?.permissions?.forEach(permission => {
+									if (permission.group === VIRTUAL_GROUPS.ALL_USERS_GROUP_INTERNAL) {
+										permission.displayGroup = VIRTUAL_GROUPS.ALL_USERS_GROUP_DISPLAY;
+									} else {
+										permission.displayGroup = permission.group;
+									}
+								});
+							});
+						}
+
 	            		$scope.recipeSamples = data;
 	                }).error(setErrorInScope.bind($scope));
 	        	}
@@ -210,11 +245,13 @@
 	        	}, true);
 
 				$scope.startResize = function (event) {
-					const resizableDiv = document.getElementById("resizableDiv");
+					const resizableDiv = document.getElementById("documentation-resizableDiv");
 					event.preventDefault();
 
 					function resize(event) {
-						resizableDiv.style.width = (resizableDiv.offsetWidth - event.movementX) + "px";
+						var w = parseInt(resizableDiv.style.width);
+						var newWidth = Math.max(20, w - event.movementX);
+						resizableDiv.style.width = newWidth + "px";
 					}
 
 					function stopResize() {
@@ -233,7 +270,7 @@
 	 * ------------------------- READING -------------------------
 	 */
 
-	app.directive('codeSnippetEditorSampleList', function($timeout, $window, Logger) {
+	app.directive('codeSnippetEditorSampleList', function($timeout, $window, Logger, SnippetEditorFocusManagerService) {
 		return {
 			link : function($scope, element) {
 
@@ -337,7 +374,7 @@
 
 				$scope.addClickListener = function() {
 					angular.element($window).on('click', function(e) {
-						if (!isPartOfCodeSnippetEditor(e.target)) {
+						if (!isPartOfCodeSnippetEditor(e.target) && !SnippetEditorFocusManagerService.isFocusTaken()) {
             				$scope.hideSampleOrCloseSelector();
             				$scope.$apply();
             			}
@@ -424,7 +461,7 @@
 		}
 	});
 
-	app.directive("codeSnippetEditorInsertableSample", function($window, WT1) {
+	app.directive("codeSnippetEditorInsertableSample", function($window, WT1, DataikuAPI, $rootScope, $q) {
 	    return {
 	    	transclude: true,
 	        scope : {
@@ -444,9 +481,14 @@
 	        },
 	        link : function($scope, element, attrs) {
 
+				$scope.currentUserPermission = {};
+				$scope.isCurrentUserAdmin = $rootScope.appConfig.admin;
+
 	            //hiding and showing sample preview and documentation
-	            $scope.showSample = function() {
-	            	$scope.displaySampleFunc($scope.sample);
+	            $scope.loadPermissionsAndShowSample = function() {
+					$scope.getCurrentUserSnippetPermissions().then(function() {
+						$scope.displaySampleFunc($scope.sample);
+					});
 	            }
 	            $scope.hideSample = function() {
 	            	$scope.hideSampleFunc();
@@ -464,6 +506,23 @@
 	                return $scope.sampleType === 'webapp_standard' || $scope.sampleType === 'webapp_shiny'
 	            }
 
+				$scope.getCurrentUserSnippetPermissions = function() {
+					if ($scope.sample?.id && $scope.sampleType && $scope.sample.origin === 'CUSTOM') {
+						return DataikuAPI.flow.snippets.getUserSnippetPermission($scope.sample.id, $scope.sampleType).success(function(data) {
+							if (data !== undefined && data !== null) {
+								$scope.currentUserPermission = {
+									isAdmin: data.isAdmin,
+									canUpdate: data.canUpdate,
+									canViewAndUse: data.canViewAndUse
+								}
+							}
+							return $scope.currentUserPermission;
+						}).error(setErrorInScope.bind($scope));
+					} else {
+						return $q.when();
+					}
+				}
+
 	            //--resolveCodeForPreviewFunc
 	        	if (typeof($scope.resolveCodeForPreviewFunc)==='undefined') {
 	        		$scope.resolveCodeForPreviewFunc = function(variation) {
@@ -479,7 +538,7 @@
 	 *  ------------------------- CREATION / EDITION / DELETION -------------------------
 	 */
 
-	app.directive('codeSnippetEditorCreateEditModalButton', function(Assert, CreateModalFromTemplate) {
+	app.directive('codeSnippetEditorCreateEditModalButton', function(Assert, CreateModalFromTemplate, SnippetEditorFocusManagerService, $timeout, $rootScope) {
 		return {
 			scope: {
 				sampleType: '=',
@@ -489,13 +548,15 @@
 	            controller: '=',
 	            reloadSampleListFunc: '=',
 	            hideSampleFunc:'=',
-	            forceMode: '='
+	            forceMode: '=',
+				currentUserPermission: '=',
 			},
 			controller: function($scope) {
 				Assert.inScope($scope, 'category');
 				$scope.MODES = {
 					CREATE : 'CREATE',
 					EDIT : 'EDIT',
+					VIEW : 'VIEW',
 					CREATE_FROM : 'CREATE_FROM'
 				};
 
@@ -504,38 +565,80 @@
 				} else if (typeof($scope.forceMode)!=='undefined' && ($scope.forceMode === $scope.MODES.CREATE || $scope.forceMode === $scope.MODES.EDIT || $scope.forceMode === $scope.MODES.CREATE_FROM)) {
 					$scope.mode = $scope.forceMode;
 				} else if ($scope.sample.origin === 'CUSTOM') {
-					$scope.mode = $scope.MODES.EDIT;
+				    if ($scope.currentUserPermission?.canUpdate || $rootScope.appConfig.admin) {
+					    $scope.mode = $scope.MODES.EDIT;
+                    } else {
+                        $scope.mode = $scope.MODES.VIEW;
+                    }
 				} else {
 					$scope.mode = $scope.MODES.CREATE_FROM;
 				}
 
-				$scope.displayPopover = function() {
+				$scope.displayPopover = function($event) {
+					if ($event) {
+						$event.stopPropagation();
+					}
+
+					var modalComponentId = 'dynamic-modal-' + new Date().getTime();
+
 					 CreateModalFromTemplate($scope.template, $scope, $scope.controller, function(newScope) {
+						 $timeout(function() {
+							 SnippetEditorFocusManagerService.register(modalComponentId);
+						 }, 0);
+
+						 newScope.$on('$destroy', function() {
+							 SnippetEditorFocusManagerService.register('transient-lock-for-modal-close');
+
+							 $timeout(function() {
+								 SnippetEditorFocusManagerService.unregister();
+							 }, 0);
+						 });
+
 						newScope.sampleType = $scope.sampleType;
 						newScope.category  = $scope.category;
 						newScope.reloadSampleListFunc = $scope.reloadSampleListFunc;
 						newScope.mode = $scope.mode;
-						if ($scope.mode === $scope.MODES.EDIT || $scope.mode === $scope.MODES.CREATE_FROM) {
+						if ($scope.mode === $scope.MODES.EDIT || $scope.mode === $scope.MODES.VIEW) {
+							newScope.currentUserPermission = $scope.currentUserPermission;
 							newScope.sample = {};
 							angular.copy($scope.sample, newScope.sample);
-							if ($scope.mode === $scope.MODES.CREATE_FROM) {
-								delete newScope.sample.id;
-							}
+						} else if($scope.mode === $scope.MODES.CREATE_FROM) {
+							newScope.currentUserPermission = { isAdmin: true, canUpdate: true, canViewAndUse: true };
+							newScope.canCurrentUserEdit = true;
+							newScope.sample = duplicateSample($scope.sample);
+							delete newScope.sample.id;
 						}
-						//not beautiful : next line is to prevent window click listener to close the code sample preview pannel
-						angular.element('.create-sample-form, .modal-backdrop').on('click', function(e) {
-							e.stopPropagation();
-						});
 		            })
 				}
+
+				function duplicateSample(sample) {
+					const newSample = angular.copy(sample);
+					newSample.title = 'Copy of ' + sample.title;
+					const ownerPermission = { group: null, user: $rootScope.appConfig.login, isAdmin: true, canUpdate: true, canViewAndUse: true };
+					newSample.permissions = [].concat(ownerPermission);
+					return newSample;
+				}
 			},
 			templateUrl : '/templates/widgets/code-snippet-editor-creation-button.html'
 		}
 	});
 
-	app.controller('CreateEditSampleController', function($scope, Assert, DataikuAPI, ActivityIndicator, $timeout, WT1, CodeMirrorSettingService) {
+	app.controller('CreateEditSampleController', function($scope, $rootScope, Assert, DataikuAPI, ActivityIndicator, $timeout, WT1, CodeMirrorSettingService, VIRTUAL_GROUPS, FeatureFlagsService) {
 		Assert.inScope($scope, 'category');
 
+		$timeout(function() {
+            $scope.$broadcast("tabSelect", "sample-pane");
+        }, 0);
+
+        $scope.isPermissionsFeatureFlagEnabled = function() {
+            return FeatureFlagsService.featureFlagEnabled('codeSamplesPermissions');
+        }
+
+		$scope.isCurrentUserAdmin = $rootScope.appConfig.admin;
+		$scope.canCurrentUserEdit = $scope.mode === 'CREATE' || $scope.currentUserPermission?.canUpdate || $scope.isCurrentUserAdmin;
+
+		getAllGroupsAllUsers();
+
 		$scope.multiLanguageSnippet = $scope.sampleType == 'webapp_standard' || $scope.sampleType == 'webapp_shiny';
 
 		if ($scope.mode == 'CREATE') {
@@ -543,7 +646,16 @@
         		variations : [{}],
         		tags : [{name:'custom', color : '#17BECF'}],
         		isShared : true,
-        		libraries : []
+        		libraries : [],
+				permissions: [
+					{
+						group: null,
+						user: $rootScope.appConfig.login,
+						isAdmin: true,
+						canUpdate: true,
+						canViewAndUse: true,
+					}
+				]
 	        };
 
 			if ($scope.sampleType == 'webapp_standard') {
@@ -581,18 +693,32 @@
 
 		$scope.modalTabState = { active : 'code'};
 
-		if ($scope.mode === 'CREATE_FROM') {
-			$scope.sample.isShared = true;
-		}
 		if (typeof($scope.sample.tags)==='undefined') {
 			$scope.sample.tags = [];
 		}
 
+		$scope.$on('paneSelected', (event, pane) => {
+			if (!pane) {
+				return;
+			}
+			$scope.activeTab = pane.slug;
+
+			$timeout(function() {
+				const editorElements = document.querySelectorAll('.CodeMirror');
+				editorElements.forEach(editorWrapperEl => {
+					if (editorWrapperEl.CodeMirror) {
+						editorWrapperEl.CodeMirror.refresh();
+					}
+				});
+			}, 0);
+		});
+
 		$scope.getEditorOptions = function(variation) {
+			const readOnly = !$scope.currentUserPermission?.canUpdate && !$scope.isCurrentUserAdmin;
 			if (variation && variation.id) {
-				return CodeMirrorSettingService.get(computeCodeMirrorMode(variation.id));
+				return CodeMirrorSettingService.get(computeCodeMirrorMode(variation.id), { readOnly: readOnly });
 			} else {
-                return CodeMirrorSettingService.get(computeCodeMirrorMode($scope.sampleType));
+                return CodeMirrorSettingService.get(computeCodeMirrorMode($scope.sampleType, { readOnly: readOnly }));
 			}
 		}
 
@@ -627,12 +753,109 @@
                 WT1.event("save-snippet", {sampleType : $scope.sampleType, saveCategory : $scope.saveCategory, id : $scope.sample.id});
 	        }).error(setErrorInScope.bind($scope));
 	    }
+
+		const buildDefaultPermission = () => {
+			return {
+				group: null,
+				displayGroup: null,
+				user: null,
+				isAdmin: false,
+				canUpdate: false,
+				canViewAndUse: true
+			}
+		};
+
+		$scope.onUsersAdded = (addedUsers) => {
+			$timeout(function() {
+				const newPermissions = addedUsers.map(user => ({ ...buildDefaultPermission(), user: user }));
+				$scope.sample.permissions = $scope.sample.permissions.concat(newPermissions);
+
+				$scope.unassignedUsers = $scope.unassignedUsers.filter((user) => !addedUsers.includes(user.login));
+				$scope.$applyAsync();
+			});
+		}
+
+		$scope.onGroupsAdded = (addedGroups) => {
+			$timeout(function() {
+				const newPermissions = addedGroups.map(group => ({
+					...buildDefaultPermission(),
+					group: group === VIRTUAL_GROUPS.ALL_USERS_GROUP_DISPLAY ? VIRTUAL_GROUPS.ALL_USERS_GROUP_INTERNAL : group,
+					displayGroup: group
+				}));
+				$scope.sample.permissions = $scope.sample.permissions.concat(newPermissions);
+
+				$scope.unassignedGroups = $scope.unassignedGroups.filter((group) => !addedGroups.includes(group));
+				$scope.$applyAsync();
+			});
+		}
+
+		$scope.cascadeAdminChange = (permission) => {
+			permission.canUpdate = true;
+			permission.canViewAndUse = true;
+		}
+
+		$scope.isSnippetShared = () => {
+			if ($scope.sample.permissions.length === 0) {
+				return false;
+			}
+
+			if ($scope.sample.permissions.length > 1) {
+				return true;
+			}
+
+			return $scope.sample.permissions.some(perm => perm.group != null);
+		}
+
+		$scope.removePermission = (index) => {
+			const removedPermission = $scope.sample.permissions.splice(index, 1);
+
+			if (removedPermission?.[0]?.displayGroup) {
+				$scope.unassignedGroups = [...$scope.unassignedGroups, removedPermission[0].displayGroup];
+			} else if (removedPermission?.[0]?.user) {
+				const userToAdd = $scope.allUsers.find(user => user.login === removedPermission[0].user);
+				if (userToAdd) {
+					$scope.unassignedUsers = [...$scope.unassignedUsers, userToAdd];
+				}
+			}
+		}
+
+		$scope.goToPane = (paneSlug) => {
+			$scope.$broadcast("tabSelect", paneSlug);
+		}
+
+		function getAllGroupsAllUsers() {
+			DataikuAPI.security.listGroups(false).success(function(allGroups) {
+				if (allGroups) {
+					allGroups.push(VIRTUAL_GROUPS.ALL_USERS_GROUP_DISPLAY);
+					allGroups.sort();
+				}
+				$scope.allGroups = allGroups;
+
+				getAllUsers();
+			}).error(setErrorInScope.bind($scope));
+		}
+
+		function getAllUsers() {
+			DataikuAPI.security.listUsers().success(function(data) {
+				$scope.allUsers = data;
+
+				$scope.allUsers.sort((a, b) => a.displayName.localeCompare(b.displayName));
+
+				updateUnassignedGroupsAndUsers();
+			}).error(setErrorInScope.bind($scope));
+		}
+
+		function updateUnassignedGroupsAndUsers() {
+			$scope.unassignedGroups = $scope.allGroups.filter(groupName => !$scope.sample?.permissions?.some(perm => perm != null && perm.displayGroup === groupName));
+			$scope.unassignedUsers = $scope.allUsers.filter(user => !$scope.sample?.permissions?.some(perm => perm != null && perm.user === user.login));
+		}
 	});
 
 	app.directive('codeSnippetEditorTagManager', function(TaggingService) {
 		return {
 			scope : {
-				sample: '='
+				sample: '=',
+				isEnabled: '=?',
 			},
 			controller: function($scope, $timeout) {
 
@@ -640,20 +863,24 @@
 				$scope.newTag = {};
 
 				$scope.deleteTag = function(tag) {
-					for (var i = 0; i<$scope.sample.tags.length; i++) {
-						if ($scope.sample.tags[i].name === tag.name) {
-							$scope.sample.tags.splice(i, 1);
-							break;
+					if ($scope.isEnabled) {
+						for (var i = 0; i<$scope.sample.tags.length; i++) {
+							if ($scope.sample.tags[i].name === tag.name) {
+								$scope.sample.tags.splice(i, 1);
+								break;
+							}
 						}
 					}
 				}
 
 				$scope.displayNewTagForm = function() {
-					$scope.isCreatingTag = true;
-					$scope.newTag = {};
-					$timeout(function(){
-						$($('.create-sample-zone input')[0]).focus();
-					}, 15);
+					if ($scope.isEnabled) {
+						$scope.isCreatingTag = true;
+						$scope.newTag = {};
+						$timeout(function(){
+							$($('.create-sample-zone input')[0]).focus();
+						}, 15);
+					}
 				}
 
 				$scope.hideNewTagForm = function() {
@@ -703,8 +930,26 @@
 
 	app.directive('codeSnippetEditorDeleteSampleButton', function() {
 		return {
+			template: `
+					<button
+					    ng-disabled="!currentUserPermission.isAdmin && !isCurrentUserAdmin"
+					    class="btn--danger"
+                        toggle="tooltip-bottom" container="body" title="Delete sample"
+					    ng-click="deleteSample()">
+						<i class="dku-icon-trash-16"></i>
+					</button>
+				`,
+			scope: {
+				currentUserPermission: '<',
+				sample: '<',
+				sampleType: '<',
+				reloadSampleListFunc: '<',
+				saveCategory: '<'
+			},
 			controller : function($scope, DataikuAPI, ActivityIndicator, $rootScope, WT1) {
 
+				$scope.isCurrentUserAdmin = $rootScope.appConfig.admin;
+
 				$scope.deleteSample = function() {
 					DataikuAPI.flow.snippets.deleteSnippet($scope.sample.id, $scope.sampleType).success(function(data) {
 			       		$scope.reloadSampleListFunc();
@@ -808,4 +1053,22 @@
 		}
 	});
 
+	app.factory('SnippetEditorFocusManagerService', function() {
+		var activeComponentId = null;
+
+		return {
+			register: function(id) {
+				activeComponentId = id;
+			},
+
+			unregister: function() {
+				activeComponentId = null;
+			},
+
+			isFocusTaken: function() {
+				return activeComponentId !== null;
+			}
+		};
+	});
+
 })();
