@@ -18,7 +18,7 @@
                     // when exporting to a new dataset in the project, refresh the flow
                     // to show the new dataset, and select this dataset
                     if (result.exportMethod == "DATASET") {
-                        GraphZoomTrackerService.setFocusItemByName("dataset", result.params.destinationDatasetName);
+                        GraphZoomTrackerService.setFocusItemById("dataset", result.params.destinationDatasetName);
                         $rootScope.$emit('datasetsListChangedFromModal');
                     }
                     showWarningsIfNeeded($scope, futureResponse)
@@ -93,7 +93,7 @@
         return svc;
     });
 
-    app.factory("ExportService", function($timeout, $q, CreateModalFromTemplate, DataikuAPI, $stateParams, LocalStorage, Logger, Collections, DatasetUtils, CachedAPICalls) {
+    app.factory("ExportService", function ($timeout, $q, CreateModalFromTemplate, DataikuAPI, $stateParams, LocalStorage, Logger, Collections, DatasetUtils, CachedAPICalls, PluginConfigUtils) {
 
         function getExportSettings(destinationType) {
             return {
@@ -268,7 +268,24 @@
                     return exportParams;
                 },
 
-                handleSelectedOptionChange : function(){
+                onOptionSelectionChange: function() {
+                    this.updateOptions();
+                    this.setExportParams();
+                },
+
+                updateOptions: function () {
+                    let selectedOptionId = this.getSelectedOptionId() || scope.exportParams.originatingOptionId;
+                    const visibilityFilter = PluginConfigUtils.shouldComponentBeVisible(window.dkuAppConfig.loadedPlugins, selectedOptionId);
+                    scope.exportModal.exportableFormats = scope.exportModal.exportOptions
+                        .filter(visibilityFilter)
+                        .filter(exportOption => exportOption.optionType == "BUILTIN_FORMAT" || exportOption.optionType == "CUSTOM_FORMAT" || exportOption.optionType == "CUSTOM_TO_FILE");
+
+                    scope.exportModal.managedExporters = scope.exportModal.exportOptions
+                        .filter(visibilityFilter)
+                        .filter(exportOption => exportOption.optionType == "CUSTOM_MANAGED");
+                },
+
+                setExportParams : function(){
                     this.cacheExportParams(scope.exportParams);
 
                     let cachedExportParams = this.getCachedExportParams();
@@ -378,12 +395,7 @@
                 DataikuAPI.exports.getOptions().success(function(data) {
                     scope.exportModal.exportOptions = data.options;
 
-                    scope.exportModal.exportableFormats = data.options.filter(function(x){
-                        return x.optionType == "BUILTIN_FORMAT" || x.optionType == "CUSTOM_FORMAT" || x.optionType == "CUSTOM_TO_FILE";
-                    });
-                    scope.exportModal.managedExporters = data.options.filter(function(x){
-                        return x.optionType == "CUSTOM_MANAGED";
-                    });
+                    scope.exportModal.updateOptions()
 
                     scope.exportModal.optionsMap = Collections.indexByField(data.options, "id");
 
@@ -413,7 +425,7 @@
                             scope.exportModal.$selectedManagedOptionId = scope.exportModal.managedExporters[0].id;
                             scope.exportParams.$exportOption = scope.exportModal.managedExporters[0];
                         }
-                        scope.exportModal.handleSelectedOptionChange();
+                        scope.exportModal.setExportParams();
                     }
 
                     Logger.info("Initialized export options", scope.exportParams);
@@ -421,7 +433,7 @@
 
                     scope.$watch("exportModal.$destinationType", function(nv, ov) {
                         if (nv && ov) {
-                            scope.exportModal.handleSelectedOptionChange();
+                            scope.exportModal.setExportParams();
                             scope.exportModal.updateModel();
                         }
                     });
@@ -451,7 +463,7 @@
 
     });
 
-    app.factory("CreateExportModal", function(ExportService, $timeout, $q, CreateModalFromTemplate, DataikuAPI, $stateParams, LocalStorage, Logger) {
+    app.factory("CreateExportModal", function(ExportService, $timeout, $q, CreateModalFromTemplate, DataikuAPI, $stateParams, LocalStorage, Logger, ConnectionsService) {
         // Example :
         //
         // features : {
@@ -467,6 +479,7 @@
         //
         return function(baseScope,dialog, featureOptions, initialExportParams) {
             var scope = baseScope.$new();
+            scope.searchConnectionsWithDescriptions = ConnectionsService.searchConnectionsWithDescriptions;
             var promise = ExportService.initExportBehavior(scope, dialog, featureOptions, scope, initialExportParams);
             CreateModalFromTemplate('/templates/exports/export_modal.html',scope);
             return promise;
@@ -543,4 +556,3 @@
     });
 
 })();
-
