@@ -30,7 +30,18 @@ app.controller('PublishIPythonController', function ($scope, $stateParams, Datai
     };
     $scope.loggedIn = $scope.appConfig.loggedIn;
     $scope.sessionExpired = false;
-    $scope.exportCreateAndPinInsight = function(notebook) {
+
+    /**
+     * Export notebook to dashboard and optionally save it before export.
+     *
+     * Warning: Implicit assumption is that a notebook can only be saved if opened on the current page, as logic will
+     * look for a specific DOM element for saving.
+     */
+    $scope.exportCreateAndPinInsight = function(notebook, saveBeforeExport) {
+        if (!saveBeforeExport) {
+            createAndPinInsight(notebook);
+            return;
+        }
         $('iframe#jupyter-iframe')[0].contentWindow.IPython.notebook.save_notebook().then(function() {
             createAndPinInsight(notebook);
         }).catch(setJupyterErrorInScope($scope));
@@ -89,6 +100,12 @@ app.controller('IPythonController', function ($scope, $stateParams, $state, $sce
         }
     });
 
+
+    $scope.canEditNotebookInCodeStudio = false;
+    DataikuAPI.codeStudioTemplates.canEditInCodeStudio($stateParams.projectKey).success(function(data) {
+        $scope.canEditNotebookInCodeStudio = data.canEdit;
+    })
+    
     var deleteNotebookWithoutConfirm = function(notebook) {
         var deferred = $q.defer();
         var deletionRequest = [{
@@ -113,11 +130,11 @@ app.controller('IPythonController', function ($scope, $stateParams, $state, $sce
         return deferred.promise;
     };
 
-    $scope.editCustomFields = function(notebook) {
-        const tor = {type: 'JUPYTER_NOTEBOOK', projectKey: $stateParams.projectKey, id: notebook.name};
+    $scope.editCustomFields = function(editingTabIndex = 0) {
+        const tor = {type: 'JUPYTER_NOTEBOOK', projectKey: $stateParams.projectKey, id: $stateParams.notebookId};
         DataikuAPI.taggableObjects.getMetadata(tor)
             .success(function(metadata) {
-                let modalScope = angular.extend($scope, {objectType: 'JUPYTER_NOTEBOOK', objectName: notebook.name, objectCustomFields: metadata.customFields || {}});
+                let modalScope = angular.extend($scope, {objectType: 'JUPYTER_NOTEBOOK', objectName: $stateParams.notebookId, objectCustomFields: metadata.customFields || {}, editingTabIndex});
                 CreateModalFromTemplate("/templates/taggable-objects/custom-fields-edit-modal.html", modalScope).then(function(customFields) {
                     metadata.customFields = angular.copy(customFields);
                     DataikuAPI.taggableObjects.setMetaData(tor, metadata)
@@ -190,15 +207,16 @@ app.controller('IPythonController', function ($scope, $stateParams, $state, $sce
         }
     };
 
-    Notification.registerEvent("logout", function(_, message) {
+    const logoutNotificationUnsubscribe = Notification.registerEvent("logout", function(_, message) {
         if (message.user === $scope.appConfig.login) {
             DataikuAPI.profile.get().error(() => {
                 $scope.loggedIn = false;
             });
         }
     });
+    $scope.$on('$destroy', logoutNotificationUnsubscribe);
 
-    Notification.registerEvent("login", function(_, message) {
+    const loginNotificationUnsubscribe = Notification.registerEvent("login", function(_, message) {
         if (message.user === $scope.appConfig.login) {
             DataikuAPI.profile.get().success(() => {
                 $scope.loggedIn = true;
@@ -206,14 +224,16 @@ app.controller('IPythonController', function ($scope, $stateParams, $state, $sce
             });
         }
     });
+    $scope.$on('$destroy', loginNotificationUnsubscribe);
 
-    Notification.registerEvent("session-expiration", (_, message) => {
+    const sessionExpirationNotificationUnsubscribe = Notification.registerEvent("session-expiration", (_, message) => {
         if (message.user === $scope.appConfig.login) {
             DataikuAPI.profile.get().error(() => {
                 $scope.sessionExpired = true;
             });
         }
     });
+    $scope.$on('$destroy', sessionExpirationNotificationUnsubscribe);
 
     $scope.forceReloadJupyterNotebook = function() {
 
@@ -243,6 +263,11 @@ app.controller('IPythonController', function ($scope, $stateParams, $state, $sce
         }).catch(setErrorInScope.bind($scope));
     }
 
+    $scope.canEditNotebookInCodeStudio = function() {
+        //DataikuAPI.codeStudioObjects.listTypes().success(function(data) {})
+        return $scope.canEditNotebookInCodeStudio;
+    }
+
     $scope.copySnippetToClipboard_ = function(variation) {
     	var stringToPutIntoClippboard = variation.code;
     	//ugly but necessary
@@ -316,7 +341,11 @@ app.controller("jupyterNotebookPageRightColumnActions", async function($controll
 });
 
 
-    app.directive('jupyterNotebookRightColumnSummary', function (DataikuAPI, $rootScope, $stateParams, QuickView, NotebooksUtils, $controller, ActiveProjectKey, ActivityIndicator, DKUtils, Dialogs, $q){
+    app.directive('jupyterNotebookRightColumnSummary', function(
+        DataikuAPI, $rootScope, $stateParams, QuickView, NotebooksUtils,
+        $controller, ActiveProjectKey, ActivityIndicator, DKUtils, Dialogs,
+        CreateModalFromTemplate, WT1, TopNav, $q
+    ){
     return {
         templateUrl :'/templates/notebooks/jupyter-notebook-right-column-summary.html',
 
@@ -339,6 +368,29 @@ app.controller("jupyterNotebookPageRightColumnActions", async function($controll
                 }).error(setErrorInScope.bind($scope));
             });
 
+            $scope.saveCustomFields = function(newCustomFields) {
+                WT1.event('custom-fields-save', {objectType: 'JUPYTER_NOTEBOOK'});
+                const tor = {type: 'JUPYTER_NOTEBOOK', projectKey: $stateParams.projectKey, id: $scope.notebookData.notebook.name};
+                const oldCustomFields = angular.copy($scope.notebookData.notebookFullInfo.customFields);
+                DataikuAPI.taggableObjects.getMetadata(tor).success(function(metadata) {
+                    metadata.customFields = newCustomFields;
+                    $scope.notebookData.notebookFullInfo.customFields = newCustomFields;
+                    DataikuAPI.taggableObjects.setMetaData(tor, metadata).success(function() {
+                        $rootScope.$broadcast('customFieldsSaved', TopNav.getItem(), newCustomFields);
+                    }).error((data, status, headers, config, statusText, xhrStatus) => {
+                        $scope.notebookData.notebookFullInfo.customFields = oldCustomFields;
+                        setErrorInScope.bind($scope)(data, status, headers, config, statusText, xhrStatus);
+                    });
+                }).error(setErrorInScope.bind($scope));
+            };
+
+            $scope.editCustomFields = function(editingTabIndex = 0) {
+                let modalScope = angular.extend($scope, {objectType: 'JUPYTER_NOTEBOOK', objectName: $scope.notebookData.notebook.name, objectCustomFields: $scope.notebookData.notebookFullInfo.customFields, editingTabIndex});
+                CreateModalFromTemplate("/templates/taggable-objects/custom-fields-edit-modal.html", modalScope).then(function(customFields) {
+                    $scope.saveCustomFields(customFields);
+                });
+            };
+
             $scope.refreshTimeline = function(){
                 var obj = $scope.selection.selectedObject;
                 if (!obj) return;
@@ -359,13 +411,9 @@ app.controller("jupyterNotebookPageRightColumnActions", async function($controll
             };
 
             $scope.getMetaData = function(){
-                $scope.insight = $scope.selection.selectedObject;
-
-                DataikuAPI.analysis.getSummary($scope.selection.selectedObject.projectKey, $scope.selection.selectedObject.id).success(function(data) {
-                    $scope.objectFullInfo = data;
-                    $scope.analysis = data.object;
-                    const d = $scope.analysis;
-                    $rootScope.$broadcast('objectMetaDataRefresh', { tags: d.tags, shortDesc: d.shortDesc, description: d.description});
+                if (!$scope.selection || !$scope.selection.selectedObject) return;
+                DataikuAPI.jupyterNotebooks.getNotebook($scope.selection.selectedObject.projectKey, $scope.selection.selectedObject.id, null).success(function(data) {
+                    $scope.notebookData.notebookFullInfo = data;
                 });
             };
 
@@ -403,6 +451,7 @@ app.controller("jupyterNotebookPageRightColumnActions", async function($controll
                 if($scope.selection.confirmedItem != $scope.selection.selectedObject) {
                     $scope.objectTimeline = null;
                 }
+                $scope.getMetaData();
             });
 
             $scope.$watch("selection.confirmedItem", function(nv, ov) {
